summaryrefslogtreecommitdiffstats
path: root/tdecore
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2023-11-13 20:33:00 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2023-11-15 23:47:11 +0900
commit303b6445011a6ed10c48ac6e1eda415e5c371264 (patch)
treeaded2a8ee5046176d3295bbf1f90f5dd73746677 /tdecore
parent141ced0c41af8726eedac425ea24cd162bcff862 (diff)
downloadtdelibs-303b6445011a6ed10c48ac6e1eda415e5c371264.tar.gz
tdelibs-303b6445011a6ed10c48ac6e1eda415e5c371264.zip
Replace Qt with TQt
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it> (cherry picked from commit c8ece3630d4d21acaf1749fc2cf660a0463070c3)
Diffstat (limited to 'tdecore')
-rw-r--r--tdecore/fixx11h.h2
-rwxr-xr-xtdecore/generate_keys.sh2
-rw-r--r--tdecore/kckey.cpp2
-rw-r--r--tdecore/kcompletion.h2
-rw-r--r--tdecore/kiconeffect.cpp2
-rw-r--r--tdecore/kkeynative.h2
-rw-r--r--tdecore/kkeyserver_x11.cpp262
-rw-r--r--tdecore/kkeyserver_x11.h20
-rw-r--r--tdecore/ktimezones.cpp8
-rw-r--r--tdecore/ktimezones.h2
-rw-r--r--tdecore/kuniqueapplication.cpp4
-rw-r--r--tdecore/kuniqueapplication.h4
-rw-r--r--tdecore/svgicons/ksvgiconpainter.cpp2
-rw-r--r--tdecore/tdeaccel.cpp2
-rw-r--r--tdecore/tdeaccel.h2
-rw-r--r--tdecore/tdeaccelmanager.cpp4
-rw-r--r--tdecore/tdeapplication.cpp44
-rw-r--r--tdecore/tdeapplication.h14
-rw-r--r--tdecore/tdeconfigdialogmanager.cpp2
-rw-r--r--tdecore/tdeglobalsettings.cpp4
-rw-r--r--tdecore/tdeshortcut.cpp8
-rw-r--r--tdecore/tdeshortcut.h18
-rw-r--r--tdecore/tdeshortcutmenu.cpp4
-rw-r--r--tdecore/tdestdaccel.cpp94
-rw-r--r--tdecore/tests/kdebugtest.cpp2
-rw-r--r--tdecore/tests/ktimezonestest.cpp12
26 files changed, 262 insertions, 262 deletions
diff --git a/tdecore/fixx11h.h b/tdecore/fixx11h.h
index e572335a1..eb6266444 100644
--- a/tdecore/fixx11h.h
+++ b/tdecore/fixx11h.h
@@ -16,7 +16,7 @@
symbols may now refer to different variables
(e.g. if X11 #defined NoButton, after this file
is included NoButton would no longer be X11's
- NoButton, but Qt::NoButton instead). At this time,
+ NoButton, but TQt::NoButton instead). At this time,
there's no conflict known that could cause problems.
The original X11 symbols are still accessible
diff --git a/tdecore/generate_keys.sh b/tdecore/generate_keys.sh
index d0fea1cdd..61987b57e 100755
--- a/tdecore/generate_keys.sh
+++ b/tdecore/generate_keys.sh
@@ -18,7 +18,7 @@ sed -n '/enum Key/!d
| sed -n 's/\s*Key_/{ "/
s/,.*$/ },/
s/ =/",/
- s/Key_/Qt::Key_/
+ s/Key_/TQt::Key_/
$s/.*/& }/
p' \
> kckey_a
diff --git a/tdecore/kckey.cpp b/tdecore/kckey.cpp
index 0feea1d49..95232f0d7 100644
--- a/tdecore/kckey.cpp
+++ b/tdecore/kckey.cpp
@@ -76,7 +76,7 @@ const KKeys kde_KKEYS[NB_KEYS] = {
{ "Direction_L", 0x1059 },
{ "Direction_R", 0x1060 },
{ "Space", 0x20 }, // translated
- { "Any", Qt::Key_Space },
+ { "Any", TQt::Key_Space },
{ "Exclam", 0x21 }, // translated
{ "QuoteDbl", 0x22 },
{ "NumberSign", 0x23 }, // translated
diff --git a/tdecore/kcompletion.h b/tdecore/kcompletion.h
index 9adf2f91a..80f61d8ad 100644
--- a/tdecore/kcompletion.h
+++ b/tdecore/kcompletion.h
@@ -873,7 +873,7 @@ public:
* the key-binding simply simply @p sum up the values of the
* modifier and the actual key. For example, to use CTRL+E as
* a key binding for one of the items, you would simply supply
- * @p "Qt::CtrlButton + Qt::Key_E" as the second argument to this
+ * @p "TQt::CtrlButton + TQt::Key_E" as the second argument to this
* function.
*
* @param item the feature whose key-binding needs to be set:
diff --git a/tdecore/kiconeffect.cpp b/tdecore/kiconeffect.cpp
index c48b1e794..3ac3ca6e8 100644
--- a/tdecore/kiconeffect.cpp
+++ b/tdecore/kiconeffect.cpp
@@ -743,7 +743,7 @@ TDEIconEffect::visualActivate(TQWidget * widget, TQRect rect)
TQPainter p(widget);
// Use NotROP to avoid having to repaint the pixmap each time.
- p.setPen(TQPen(Qt::black, 2, Qt::DotLine));
+ p.setPen(TQPen(TQt::black, 2, TQt::DotLine));
p.setRasterOp(TQt::NotROP);
// The spacing between the rects we draw.
diff --git a/tdecore/kkeynative.h b/tdecore/kkeynative.h
index e2774417d..ffcc13a69 100644
--- a/tdecore/kkeynative.h
+++ b/tdecore/kkeynative.h
@@ -111,7 +111,7 @@ class TDECORE_EXPORT KKeyNative
/**
* Returns the qt key code.
* @return the qt key code or 0 if there is no key set.
- * @see Qt::Key
+ * @see TQt::Key
*/
int keyCodeQt() const;
diff --git a/tdecore/kkeyserver_x11.cpp b/tdecore/kkeyserver_x11.cpp
index bb46338f4..ebe06de97 100644
--- a/tdecore/kkeyserver_x11.cpp
+++ b/tdecore/kkeyserver_x11.cpp
@@ -48,14 +48,14 @@
#else
# include <kckey.h>
# define X11_ONLY(arg)
-# define XK_ISO_Left_Tab Qt::Key_Backtab
-# define XK_BackSpace Qt::Key_Backspace
-# define XK_Sys_Req Qt::Key_SysReq
-# define XK_Caps_Lock Qt::Key_CapsLock
-# define XK_Num_Lock Qt::Key_NumLock
-# define XK_Scroll_Lock Qt::Key_ScrollLock
-# define XK_Prior Qt::Key_Prior
-# define XK_Next Qt::Key_Next
+# define XK_ISO_Left_Tab TQt::Key_Backtab
+# define XK_BackSpace TQt::Key_Backspace
+# define XK_Sys_Req TQt::Key_SysReq
+# define XK_Caps_Lock TQt::Key_CapsLock
+# define XK_Num_Lock TQt::Key_NumLock
+# define XK_Scroll_Lock TQt::Key_ScrollLock
+# define XK_Prior TQt::Key_Prior
+# define XK_Next TQt::Key_Next
#endif
namespace KKeyServer
@@ -108,9 +108,9 @@ struct TransKey {
static ModInfo g_rgModInfo[KKey::MOD_FLAG_COUNT] =
{
- { KKey::SHIFT, Qt::SHIFT, X11_ONLY(ShiftMask) I18N_NOOP("Shift"), TQString() },
- { KKey::CTRL, Qt::CTRL, X11_ONLY(ControlMask) I18N_NOOP("Ctrl"), TQString() },
- { KKey::ALT, Qt::ALT, X11_ONLY(Mod1Mask) I18N_NOOP("Alt"), TQString() },
+ { KKey::SHIFT, TQt::SHIFT, X11_ONLY(ShiftMask) I18N_NOOP("Shift"), TQString() },
+ { KKey::CTRL, TQt::CTRL, X11_ONLY(ControlMask) I18N_NOOP("Ctrl"), TQString() },
+ { KKey::ALT, TQt::ALT, X11_ONLY(Mod1Mask) I18N_NOOP("Alt"), TQString() },
{ KKey::WIN, KKey::QtWIN, X11_ONLY(Mod4Mask) I18N_NOOP("Win"), TQString() }
};
@@ -156,85 +156,85 @@ static SymVariation g_rgSymVariation[] =
// These are the X equivalents to the Qt keycodes 0x1000 - 0x1026
static const TransKey g_rgQtToSymX[] =
{
- { Qt::Key_Escape, XK_Escape },
- { Qt::Key_Tab, XK_Tab },
- { Qt::Key_Backtab, XK_ISO_Left_Tab },
- { Qt::Key_Backspace, XK_BackSpace },
- { Qt::Key_Return, XK_Return },
- { Qt::Key_Enter, XK_KP_Enter },
- { Qt::Key_Insert, XK_Insert },
- { Qt::Key_Delete, XK_Delete },
- { Qt::Key_Pause, XK_Pause },
+ { TQt::Key_Escape, XK_Escape },
+ { TQt::Key_Tab, XK_Tab },
+ { TQt::Key_Backtab, XK_ISO_Left_Tab },
+ { TQt::Key_Backspace, XK_BackSpace },
+ { TQt::Key_Return, XK_Return },
+ { TQt::Key_Enter, XK_KP_Enter },
+ { TQt::Key_Insert, XK_Insert },
+ { TQt::Key_Delete, XK_Delete },
+ { TQt::Key_Pause, XK_Pause },
#ifdef sun
- { Qt::Key_Print, XK_F22 },
+ { TQt::Key_Print, XK_F22 },
#else
- { Qt::Key_Print, XK_Print },
+ { TQt::Key_Print, XK_Print },
#endif
- { Qt::Key_SysReq, XK_Sys_Req },
- { Qt::Key_Home, XK_Home },
- { Qt::Key_End, XK_End },
- { Qt::Key_Left, XK_Left },
- { Qt::Key_Up, XK_Up },
- { Qt::Key_Right, XK_Right },
- { Qt::Key_Down, XK_Down },
+ { TQt::Key_SysReq, XK_Sys_Req },
+ { TQt::Key_Home, XK_Home },
+ { TQt::Key_End, XK_End },
+ { TQt::Key_Left, XK_Left },
+ { TQt::Key_Up, XK_Up },
+ { TQt::Key_Right, XK_Right },
+ { TQt::Key_Down, XK_Down },
{ TQt::Key_Prior, XK_Prior },
{ TQt::Key_Next, XK_Next },
- //{ Qt::Key_Shift, 0 },
- //{ Qt::Key_Control, 0 },
- //{ Qt::Key_Meta, 0 },
- //{ Qt::Key_Alt, 0 },
- { Qt::Key_CapsLock, XK_Caps_Lock },
- { Qt::Key_NumLock, XK_Num_Lock },
- { Qt::Key_ScrollLock, XK_Scroll_Lock },
- { Qt::Key_F1, XK_F1 },
- { Qt::Key_F2, XK_F2 },
- { Qt::Key_F3, XK_F3 },
- { Qt::Key_F4, XK_F4 },
- { Qt::Key_F5, XK_F5 },
- { Qt::Key_F6, XK_F6 },
- { Qt::Key_F7, XK_F7 },
- { Qt::Key_F8, XK_F8 },
- { Qt::Key_F9, XK_F9 },
- { Qt::Key_F10, XK_F10 },
- { Qt::Key_F11, XK_F11 },
- { Qt::Key_F12, XK_F12 },
- { Qt::Key_F13, XK_F13 },
- { Qt::Key_F14, XK_F14 },
- { Qt::Key_F15, XK_F15 },
- { Qt::Key_F16, XK_F16 },
- { Qt::Key_F17, XK_F17 },
- { Qt::Key_F18, XK_F18 },
- { Qt::Key_F19, XK_F19 },
- { Qt::Key_F20, XK_F20 },
- { Qt::Key_F21, XK_F21 },
- { Qt::Key_F22, XK_F22 },
- { Qt::Key_F23, XK_F23 },
- { Qt::Key_F24, XK_F24 },
- { Qt::Key_F25, XK_F25 },
- { Qt::Key_F26, XK_F26 },
- { Qt::Key_F27, XK_F27 },
- { Qt::Key_F28, XK_F28 },
- { Qt::Key_F29, XK_F29 },
- { Qt::Key_F30, XK_F30 },
- { Qt::Key_F31, XK_F31 },
- { Qt::Key_F32, XK_F32 },
- { Qt::Key_F33, XK_F33 },
- { Qt::Key_F34, XK_F34 },
- { Qt::Key_F35, XK_F35 },
- { Qt::Key_Super_L, XK_Super_L },
- { Qt::Key_Super_R, XK_Super_R },
- { Qt::Key_Menu, XK_Menu },
- { Qt::Key_Hyper_L, XK_Hyper_L },
- { Qt::Key_Hyper_R, XK_Hyper_R },
- { Qt::Key_Help, XK_Help },
- //{ Qt::Key_Direction_L, XK_Direction_L }, These keys don't exist in X11
- //{ Qt::Key_Direction_R, XK_Direction_R },
+ //{ TQt::Key_Shift, 0 },
+ //{ TQt::Key_Control, 0 },
+ //{ TQt::Key_Meta, 0 },
+ //{ TQt::Key_Alt, 0 },
+ { TQt::Key_CapsLock, XK_Caps_Lock },
+ { TQt::Key_NumLock, XK_Num_Lock },
+ { TQt::Key_ScrollLock, XK_Scroll_Lock },
+ { TQt::Key_F1, XK_F1 },
+ { TQt::Key_F2, XK_F2 },
+ { TQt::Key_F3, XK_F3 },
+ { TQt::Key_F4, XK_F4 },
+ { TQt::Key_F5, XK_F5 },
+ { TQt::Key_F6, XK_F6 },
+ { TQt::Key_F7, XK_F7 },
+ { TQt::Key_F8, XK_F8 },
+ { TQt::Key_F9, XK_F9 },
+ { TQt::Key_F10, XK_F10 },
+ { TQt::Key_F11, XK_F11 },
+ { TQt::Key_F12, XK_F12 },
+ { TQt::Key_F13, XK_F13 },
+ { TQt::Key_F14, XK_F14 },
+ { TQt::Key_F15, XK_F15 },
+ { TQt::Key_F16, XK_F16 },
+ { TQt::Key_F17, XK_F17 },
+ { TQt::Key_F18, XK_F18 },
+ { TQt::Key_F19, XK_F19 },
+ { TQt::Key_F20, XK_F20 },
+ { TQt::Key_F21, XK_F21 },
+ { TQt::Key_F22, XK_F22 },
+ { TQt::Key_F23, XK_F23 },
+ { TQt::Key_F24, XK_F24 },
+ { TQt::Key_F25, XK_F25 },
+ { TQt::Key_F26, XK_F26 },
+ { TQt::Key_F27, XK_F27 },
+ { TQt::Key_F28, XK_F28 },
+ { TQt::Key_F29, XK_F29 },
+ { TQt::Key_F30, XK_F30 },
+ { TQt::Key_F31, XK_F31 },
+ { TQt::Key_F32, XK_F32 },
+ { TQt::Key_F33, XK_F33 },
+ { TQt::Key_F34, XK_F34 },
+ { TQt::Key_F35, XK_F35 },
+ { TQt::Key_Super_L, XK_Super_L },
+ { TQt::Key_Super_R, XK_Super_R },
+ { TQt::Key_Menu, XK_Menu },
+ { TQt::Key_Hyper_L, XK_Hyper_L },
+ { TQt::Key_Hyper_R, XK_Hyper_R },
+ { TQt::Key_Help, XK_Help },
+ //{ TQt::Key_Direction_L, XK_Direction_L }, These keys don't exist in X11
+ //{ TQt::Key_Direction_R, XK_Direction_R },
{ '/', XK_KP_Divide },
{ '*', XK_KP_Multiply },
{ '-', XK_KP_Subtract },
{ '+', XK_KP_Add },
- { Qt::Key_Return, XK_KP_Enter }
+ { TQt::Key_Return, XK_KP_Enter }
#if TQT_VERSION >= 0x030100
// the next lines are taken from XFree > 4.0 (X11/XF86keysyms.h), defining some special
@@ -285,46 +285,46 @@ static const TransKey g_rgQtToSymX[] =
#define XF86XK_KbdBrightnessDown 0x1008FF06 /* Keyboards may be lit */
// end of XF86keysyms.h
,
- { Qt::Key_Standby, XF86XK_Standby },
- { Qt::Key_VolumeDown, XF86XK_AudioLowerVolume },
- { Qt::Key_VolumeMute, XF86XK_AudioMute },
- { Qt::Key_VolumeUp, XF86XK_AudioRaiseVolume },
- { Qt::Key_MediaPlay, XF86XK_AudioPlay },
- { Qt::Key_MediaStop, XF86XK_AudioStop },
+ { TQt::Key_Standby, XF86XK_Standby },
+ { TQt::Key_VolumeDown, XF86XK_AudioLowerVolume },
+ { TQt::Key_VolumeMute, XF86XK_AudioMute },
+ { TQt::Key_VolumeUp, XF86XK_AudioRaiseVolume },
+ { TQt::Key_MediaPlay, XF86XK_AudioPlay },
+ { TQt::Key_MediaStop, XF86XK_AudioStop },
{ TQt::Key_MediaPrev, XF86XK_AudioPrev },
- { Qt::Key_MediaNext, XF86XK_AudioNext },
- { Qt::Key_HomePage, XF86XK_HomePage },
- { Qt::Key_LaunchMail, XF86XK_Mail },
- { Qt::Key_Search, XF86XK_Search },
- { Qt::Key_MediaRecord, XF86XK_AudioRecord },
- { Qt::Key_LaunchMedia, XF86XK_AudioMedia },
- { Qt::Key_Launch1, XF86XK_Calculator },
- { Qt::Key_Back, XF86XK_Back },
- { Qt::Key_Forward, XF86XK_Forward },
- { Qt::Key_Stop, XF86XK_Stop },
- { Qt::Key_Refresh, XF86XK_Refresh },
- { Qt::Key_Favorites, XF86XK_Favorites },
- { Qt::Key_Launch0, XF86XK_MyComputer },
- { Qt::Key_OpenUrl, XF86XK_OpenURL },
- { Qt::Key_Launch2, XF86XK_Launch0 },
- { Qt::Key_Launch3, XF86XK_Launch1 },
- { Qt::Key_Launch4, XF86XK_Launch2 },
- { Qt::Key_Launch5, XF86XK_Launch3 },
- { Qt::Key_Launch6, XF86XK_Launch4 },
- { Qt::Key_Launch7, XF86XK_Launch5 },
- { Qt::Key_Launch8, XF86XK_Launch6 },
- { Qt::Key_Launch9, XF86XK_Launch7 },
- { Qt::Key_LaunchA, XF86XK_Launch8 },
- { Qt::Key_LaunchB, XF86XK_Launch9 },
- { Qt::Key_LaunchC, XF86XK_LaunchA },
- { Qt::Key_LaunchD, XF86XK_LaunchB },
- { Qt::Key_LaunchE, XF86XK_LaunchC },
- { Qt::Key_LaunchF, XF86XK_LaunchD },
- { Qt::Key_MonBrightnessUp, XF86XK_MonBrightnessUp },
- { Qt::Key_MonBrightnessDown, XF86XK_MonBrightnessDown },
- { Qt::Key_KeyboardLightOnOff, XF86XK_KbdLightOnOff },
- { Qt::Key_KeyboardBrightnessUp, XF86XK_KbdBrightnessUp },
- { Qt::Key_KeyboardBrightnessDown, XF86XK_KbdBrightnessDown },
+ { TQt::Key_MediaNext, XF86XK_AudioNext },
+ { TQt::Key_HomePage, XF86XK_HomePage },
+ { TQt::Key_LaunchMail, XF86XK_Mail },
+ { TQt::Key_Search, XF86XK_Search },
+ { TQt::Key_MediaRecord, XF86XK_AudioRecord },
+ { TQt::Key_LaunchMedia, XF86XK_AudioMedia },
+ { TQt::Key_Launch1, XF86XK_Calculator },
+ { TQt::Key_Back, XF86XK_Back },
+ { TQt::Key_Forward, XF86XK_Forward },
+ { TQt::Key_Stop, XF86XK_Stop },
+ { TQt::Key_Refresh, XF86XK_Refresh },
+ { TQt::Key_Favorites, XF86XK_Favorites },
+ { TQt::Key_Launch0, XF86XK_MyComputer },
+ { TQt::Key_OpenUrl, XF86XK_OpenURL },
+ { TQt::Key_Launch2, XF86XK_Launch0 },
+ { TQt::Key_Launch3, XF86XK_Launch1 },
+ { TQt::Key_Launch4, XF86XK_Launch2 },
+ { TQt::Key_Launch5, XF86XK_Launch3 },
+ { TQt::Key_Launch6, XF86XK_Launch4 },
+ { TQt::Key_Launch7, XF86XK_Launch5 },
+ { TQt::Key_Launch8, XF86XK_Launch6 },
+ { TQt::Key_Launch9, XF86XK_Launch7 },
+ { TQt::Key_LaunchA, XF86XK_Launch8 },
+ { TQt::Key_LaunchB, XF86XK_Launch9 },
+ { TQt::Key_LaunchC, XF86XK_LaunchA },
+ { TQt::Key_LaunchD, XF86XK_LaunchB },
+ { TQt::Key_LaunchE, XF86XK_LaunchC },
+ { TQt::Key_LaunchF, XF86XK_LaunchD },
+ { TQt::Key_MonBrightnessUp, XF86XK_MonBrightnessUp },
+ { TQt::Key_MonBrightnessDown, XF86XK_MonBrightnessDown },
+ { TQt::Key_KeyboardLightOnOff, XF86XK_KbdLightOnOff },
+ { TQt::Key_KeyboardBrightnessUp, XF86XK_KbdBrightnessUp },
+ { TQt::Key_KeyboardBrightnessDown, XF86XK_KbdBrightnessDown },
#endif
};
#endif //Q_WS_X11
@@ -416,7 +416,7 @@ bool Sym::initQt( int keyQt )
{
int symQt = keyQt & 0xffff;
- if( (keyQt & Qt::UNICODE_ACCEL) || symQt < 0x1000 ) {
+ if( (keyQt & TQt::UNICODE_ACCEL) || symQt < 0x1000 ) {
m_sym = TQChar(symQt).lower().unicode();
return true;
}
@@ -433,8 +433,8 @@ bool Sym::initQt( int keyQt )
}
m_sym = 0;
- if( symQt != Qt::Key_Shift && symQt != Qt::Key_Control && symQt != Qt::Key_Alt &&
- symQt != Qt::Key_Meta && symQt != Qt::Key_Direction_L && symQt != Qt::Key_Direction_R )
+ if( symQt != TQt::Key_Shift && symQt != TQt::Key_Control && symQt != TQt::Key_Alt &&
+ symQt != TQt::Key_Meta && symQt != TQt::Key_Direction_L && symQt != TQt::Key_Direction_R )
kdDebug(125) << "Sym::initQt( " << TQString::number(keyQt,16) << " ): failed to convert key." << endl;
return false;
#elif defined(Q_WS_MACX)
@@ -495,7 +495,7 @@ int Sym::qt() const
return m_sym;
#elif defined(Q_WS_X11)
if( m_sym < 0x3000 )
- return m_sym | Qt::UNICODE_ACCEL;
+ return m_sym | TQt::UNICODE_ACCEL;
for( uint i = 0; i < sizeof(g_rgQtToSymX)/sizeof(TransKey); i++ )
if( g_rgQtToSymX[i].keySymX == m_sym )
@@ -648,10 +648,10 @@ bool keyQtToMod( int keyQt, uint& mod )
{
mod = 0;
- if( keyQt & Qt::SHIFT ) mod |= KKey::SHIFT;
- if( keyQt & Qt::CTRL ) mod |= KKey::CTRL;
- if( keyQt & Qt::ALT ) mod |= KKey::ALT;
- if( keyQt & Qt::META ) mod |= KKey::WIN;
+ if( keyQt & TQt::SHIFT ) mod |= KKey::SHIFT;
+ if( keyQt & TQt::CTRL ) mod |= KKey::CTRL;
+ if( keyQt & TQt::ALT ) mod |= KKey::ALT;
+ if( keyQt & TQt::META ) mod |= KKey::WIN;
return true;
}
@@ -688,9 +688,9 @@ bool modXToModQt( uint modX, int& modQt )
TDECORE_EXPORT int qtButtonStateToMod( TQt::ButtonState s )
{
int modQt = 0;
- if (s & Qt::ShiftButton) modQt |= KKey::SHIFT;
- if (s & Qt::ControlButton) modQt |= KKey::CTRL;
- if (s & Qt::AltButton) modQt |= KKey::ALT;
+ if (s & TQt::ShiftButton) modQt |= KKey::SHIFT;
+ if (s & TQt::ControlButton) modQt |= KKey::CTRL;
+ if (s & TQt::AltButton) modQt |= KKey::ALT;
return modQt;
}
@@ -841,7 +841,7 @@ uint stringUserToMod( const TQString& mod )
if( keySymQt < 0x1000 ) {
// For reasons unbeknownst to me, Qt converts 'a-z' to 'A-Z'.
// So convert it back to lowercase if SHIFT isn't held down.
- if( keySymQt >= Qt::Key_A && keySymQt <= Qt::Key_Z && !(keyCombQt & Qt::SHIFT) )
+ if( keySymQt >= TQt::Key_A && keySymQt <= TQt::Key_Z && !(keyCombQt & TQt::SHIFT) )
keySymQt = tolower( keySymQt );
keySymX = keySymQt;
}
diff --git a/tdecore/kkeyserver_x11.h b/tdecore/kkeyserver_x11.h
index 090372ef1..7632984e7 100644
--- a/tdecore/kkeyserver_x11.h
+++ b/tdecore/kkeyserver_x11.h
@@ -71,7 +71,7 @@ namespace KKeyServer
* Initializes the symbol with the given Qt key code.
* @param keyQt the qt key code
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
*/
bool initQt( int keyQt );
@@ -153,7 +153,7 @@ namespace KKeyServer
* @param key the key to get the data from
* @param bQt true to take the Qt keycode, false
* for the native key code
- * @see Qt::Key
+ * @see TQt::Key
* @see KKeyNative
*/
bool init( const KKey& key, bool bQt );
@@ -162,7 +162,7 @@ namespace KKeyServer
* Checks whether the key code is a native code.
* @return true if native code of the window system,
* false if it is a Qt keycode
- * @see Qt::Key
+ * @see TQt::Key
* @see KKeyNative
*/
bool isNative() const { return m_code != CODE_FOR_QT; }
@@ -351,7 +351,7 @@ namespace KKeyServer
* @param keyQt the qt key code
* @param sym if successful, the symbol will be written here
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
* @see Sym
*/
TDECORE_EXPORT bool keyQtToSym( int keyQt, uint& sym );
@@ -362,7 +362,7 @@ namespace KKeyServer
* @param keyQt the qt key code
* @param mod if successful, the modifiers will be written here
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
*/
TDECORE_EXPORT bool keyQtToMod( int keyQt, uint& mod );
@@ -371,7 +371,7 @@ namespace KKeyServer
* @param sym the symbol
* @param keyQt if successful, the qt key code will be written here
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
* @see Sym
*/
TDECORE_EXPORT bool symToKeyQt( uint sym, int& keyQt );
@@ -383,7 +383,7 @@ namespace KKeyServer
* @param modQt the mask of Qt key code modifiers will be written here,
* if successful
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
* @see KKey
*/
TDECORE_EXPORT bool modToModQt( uint mod, int& modQt );
@@ -406,7 +406,7 @@ namespace KKeyServer
* @param modQt the mask of Qt key code modifiers will be written here
* if successful
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
*/
//wrapped for win32
TDECORE_EXPORT bool modXToModQt( uint modX, int& modQt );
@@ -414,7 +414,7 @@ namespace KKeyServer
/**
* Converts the Qt-compatible button state to x11 modifier.
*/
- TDECORE_EXPORT int qtButtonStateToMod( Qt::ButtonState s );
+ TDECORE_EXPORT int qtButtonStateToMod( TQt::ButtonState s );
/**
* Converts the mask of ORed X11 modifiers to
@@ -435,7 +435,7 @@ namespace KKeyServer
* @param modX the mask of ORed X11 modifiers
* @param symX if successful, the X11 symbol will be written here
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
* @see Sym
*/
TDECORE_EXPORT bool codeXToSym( uchar codeX, uint modX, uint& symX );
diff --git a/tdecore/ktimezones.cpp b/tdecore/ktimezones.cpp
index 2dd248cfe..ce818bd87 100644
--- a/tdecore/ktimezones.cpp
+++ b/tdecore/ktimezones.cpp
@@ -245,7 +245,7 @@ TQDateTime KTimezone::convert(const KTimezone *newZone, const TQDateTime &dateTi
::setenv("TZ", newZone->name().utf8(), 1);
tzset();
TQDateTime remoteTime;
- remoteTime.setTime_t(utc, Qt::LocalTime);
+ remoteTime.setTime_t(utc, TQt::LocalTime);
// Now restore things
if (!originalZone)
@@ -280,7 +280,7 @@ TQString KTimezone::name() const
return m_name;
}
-int KTimezone::offset(Qt::TimeSpec basisSpec) const
+int KTimezone::offset(TQt::TimeSpec basisSpec) const
{
char *originalZone = ::getenv("TZ");
@@ -290,7 +290,7 @@ int KTimezone::offset(Qt::TimeSpec basisSpec) const
// Set the timezone and find out what time it is there compared to the basis.
::setenv("TZ", m_name.utf8(), 1);
tzset();
- TQDateTime remoteTime = TQDateTime::currentDateTime(Qt::LocalTime);
+ TQDateTime remoteTime = TQDateTime::currentDateTime(TQt::LocalTime);
int offset = remoteTime.secsTo(basisTime);
// Now restore things
@@ -605,7 +605,7 @@ const KTimezone *KTimezones::local()
for (ZoneMap::Iterator it = m_zones->begin(); it != m_zones->end(); ++it)
{
KTimezone *zone = it.data();
- int candidateOffset = QABS(zone->offset(Qt::LocalTime));
+ int candidateOffset = QABS(zone->offset(TQt::LocalTime));
if (zone->parse(matcher) && matcher.test() && (candidateOffset < bestOffset))
{
// kdError() << "local=" << zone->name() << endl;
diff --git a/tdecore/ktimezones.h b/tdecore/ktimezones.h
index 339cbf5bf..bcb1e7a99 100644
--- a/tdecore/ktimezones.h
+++ b/tdecore/ktimezones.h
@@ -156,7 +156,7 @@ public:
*
* @return offset in seconds.
*/
- int offset(Qt::TimeSpec basisSpec = Qt::UTC) const;
+ int offset(TQt::TimeSpec basisSpec = TQt::UTC) const;
/**
* Returns the offset of the given timezone to UTC at the given
diff --git a/tdecore/kuniqueapplication.cpp b/tdecore/kuniqueapplication.cpp
index 12c9c1297..8dd6185d0 100644
--- a/tdecore/kuniqueapplication.cpp
+++ b/tdecore/kuniqueapplication.cpp
@@ -334,8 +334,8 @@ KUniqueApplication::KUniqueApplication(bool allowStyles, bool GUIenabled, bool c
#ifdef Q_WS_X11
-KUniqueApplication::KUniqueApplication(Display *display, Qt::HANDLE visual,
- Qt::HANDLE colormap, bool allowStyles, bool configUnique)
+KUniqueApplication::KUniqueApplication(Display *display, TQt::HANDLE visual,
+ TQt::HANDLE colormap, bool allowStyles, bool configUnique)
: TDEApplication( display, visual, colormap, allowStyles, initHack( configUnique )),
DCOPObject(TDECmdLineArgs::about->appName())
{
diff --git a/tdecore/kuniqueapplication.h b/tdecore/kuniqueapplication.h
index 97dc6a6bf..500cb3f26 100644
--- a/tdecore/kuniqueapplication.h
+++ b/tdecore/kuniqueapplication.h
@@ -90,8 +90,8 @@ public:
* @since KDE 3.3
*/
KUniqueApplication( Display *display,
- Qt::HANDLE visual=0,
- Qt::HANDLE colormap=0,
+ TQt::HANDLE visual=0,
+ TQt::HANDLE colormap=0,
bool allowStyles=true,
bool configUnique=false);
#endif
diff --git a/tdecore/svgicons/ksvgiconpainter.cpp b/tdecore/svgicons/ksvgiconpainter.cpp
index e0e2a2ce9..7c2859656 100644
--- a/tdecore/svgicons/ksvgiconpainter.cpp
+++ b/tdecore/svgicons/ksvgiconpainter.cpp
@@ -57,7 +57,7 @@ public:
m_clipSVP = 0;
- m_fillColor = Qt::black;
+ m_fillColor = TQt::black;
m_useFill = true;
m_useStroke = false;
diff --git a/tdecore/tdeaccel.cpp b/tdecore/tdeaccel.cpp
index 5430c2529..eaa33a9c0 100644
--- a/tdecore/tdeaccel.cpp
+++ b/tdecore/tdeaccel.cpp
@@ -49,7 +49,7 @@
//---------------------------------------------------------------------
//
// In TDEAccelEventHandler::x11Event we do our own X11 keyboard event handling
-// This allows us to map the Win key to Qt::MetaButton, Qt does not know about
+// This allows us to map the Win key to TQt::MetaButton, Qt does not know about
// the Win key.
//
// TDEAccelEventHandler::x11Event will generate an AccelOverride event. The
diff --git a/tdecore/tdeaccel.h b/tdecore/tdeaccel.h
index 0eb022912..8c806ad3f 100644
--- a/tdecore/tdeaccel.h
+++ b/tdecore/tdeaccel.h
@@ -74,7 +74,7 @@ class TDEAccelPrivate;
* // Insert an action "Scroll Up" which is associated with the "Up" key:
* pAccel->insert( "Scroll Up", i18n("Scroll up"),
* i18n("Scroll up the current document by one line."),
- * Qt::Key_Up, this, TQT_SLOT(slotScrollUp()) );
+ * TQt::Key_Up, this, TQT_SLOT(slotScrollUp()) );
* // Insert an standard acclerator action.
* pAccel->insert( TDEStdAccel::Print, this, TQT_SLOT(slotPrint()) );
*
diff --git a/tdecore/tdeaccelmanager.cpp b/tdecore/tdeaccelmanager.cpp
index 8d352e027..2c0e10aa3 100644
--- a/tdecore/tdeaccelmanager.cpp
+++ b/tdecore/tdeaccelmanager.cpp
@@ -329,8 +329,8 @@ void TDEAcceleratorManagerPrivate::manageWidget(TQWidget *w, Item *item)
if ( !label->buddy() )
label = 0;
else {
- if ( label->textFormat() == Qt::RichText ||
- ( label->textFormat() == Qt::AutoText &&
+ if ( label->textFormat() == TQt::RichText ||
+ ( label->textFormat() == TQt::AutoText &&
TQStyleSheet::mightBeRichText( label->text() ) ) )
label = 0;
}
diff --git a/tdecore/tdeapplication.cpp b/tdecore/tdeapplication.cpp
index d3ff5bcb2..af8d53e91 100644
--- a/tdecore/tdeapplication.cpp
+++ b/tdecore/tdeapplication.cpp
@@ -586,7 +586,7 @@ bool TDEApplication::notify(TQObject *receiver, TQEvent *event)
}
}
// Ctrl-U deletes from start of line.
- if (key == KKey(Qt::CTRL + Qt::Key_U))
+ if (key == KKey(TQt::CTRL + TQt::Key_U))
{
if (t == TQEvent::KeyPress)
{
@@ -817,7 +817,7 @@ TDEApplication::TDEApplication( Display *dpy, bool allowStyles ) :
d->m_KAppDCOPInterface = new KAppDCOPInterface(this);
}
-TDEApplication::TDEApplication( Display *dpy, bool disable_argb, Qt::HANDLE visual, Qt::HANDLE colormap, bool allowStyles ) :
+TDEApplication::TDEApplication( Display *dpy, bool disable_argb, TQt::HANDLE visual, TQt::HANDLE colormap, bool allowStyles ) :
TQApplication( dpy, *TDECmdLineArgs::tqt_argc(), *TDECmdLineArgs::tqt_argv(),
disable_argb?visual:getX11RGBAVisual(dpy), disable_argb?colormap:getX11RGBAColormap(dpy) ),
TDEInstance( TDECmdLineArgs::about), display(0L), d (new TDEApplicationPrivate)
@@ -834,7 +834,7 @@ TDEApplication::TDEApplication( Display *dpy, bool disable_argb, Qt::HANDLE visu
d->m_KAppDCOPInterface = new KAppDCOPInterface(this);
}
-TDEApplication::TDEApplication( Display *dpy, Qt::HANDLE visual, Qt::HANDLE colormap,
+TDEApplication::TDEApplication( Display *dpy, TQt::HANDLE visual, TQt::HANDLE colormap,
bool allowStyles ) :
TQApplication( dpy, *TDECmdLineArgs::tqt_argc(), *TDECmdLineArgs::tqt_argv(),
visual?visual:getX11RGBAVisual(dpy), colormap?colormap:getX11RGBAColormap(dpy) ),
@@ -853,7 +853,7 @@ TDEApplication::TDEApplication( Display *dpy, Qt::HANDLE visual, Qt::HANDLE colo
d->m_KAppDCOPInterface = new KAppDCOPInterface(this);
}
-TDEApplication::TDEApplication( Display *dpy, Qt::HANDLE visual, Qt::HANDLE colormap,
+TDEApplication::TDEApplication( Display *dpy, TQt::HANDLE visual, TQt::HANDLE colormap,
bool allowStyles, TDEInstance * _instance ) :
TQApplication( dpy, *TDECmdLineArgs::tqt_argc(), *TDECmdLineArgs::tqt_argv(),
visual?visual:getX11RGBAVisual(dpy), colormap?colormap:getX11RGBAColormap(dpy) ),
@@ -2032,23 +2032,23 @@ Display* TDEApplication::openX11RGBADisplay() {
return dpy;
}
-Qt::HANDLE TDEApplication::getX11RGBAVisual(Display *dpy) {
+TQt::HANDLE TDEApplication::getX11RGBAVisual(Display *dpy) {
getX11RGBAInformation(dpy);
if (TDEApplication::isCompositionManagerAvailable() == true) {
return argb_x11_visual;
}
else {
- return (Qt::HANDLE)NULL;
+ return (TQt::HANDLE)NULL;
}
}
-Qt::HANDLE TDEApplication::getX11RGBAColormap(Display *dpy) {
+TQt::HANDLE TDEApplication::getX11RGBAColormap(Display *dpy) {
getX11RGBAInformation(dpy);
if (TDEApplication::isCompositionManagerAvailable() == true) {
return argb_x11_colormap;
}
else {
- return (Qt::HANDLE)NULL;
+ return (TQt::HANDLE)NULL;
}
}
@@ -2089,8 +2089,8 @@ void TDEApplication::getX11RGBAInformation(Display *dpy) {
}
if( argb_visual ) {
- argb_x11_visual = Qt::HANDLE( visual );
- argb_x11_colormap = Qt::HANDLE( colormap );
+ argb_x11_visual = TQt::HANDLE( visual );
+ argb_x11_colormap = TQt::HANDLE( colormap );
argb_visual = true;
return;
}
@@ -2144,11 +2144,11 @@ Display* TDEApplication::openX11RGBADisplay() {
return 0;
}
-Qt::HANDLE TDEApplication::getX11RGBAVisual(Display *dpy) {
+TQt::HANDLE TDEApplication::getX11RGBAVisual(Display *dpy) {
return 0;
}
-Qt::HANDLE TDEApplication::getX11RGBAColormap(Display *dpy) {
+TQt::HANDLE TDEApplication::getX11RGBAColormap(Display *dpy) {
return 0;
}
@@ -2462,12 +2462,12 @@ TQPalette TDEApplication::createApplicationPalette( TDEConfig *config, int contr
if (v > 128)
// dark bg, light fg - need a darker disabled fg
disfg = disfg.dark(lowlightVal);
- else if (disfg != Qt::black)
+ else if (disfg != TQt::black)
// light bg, dark fg - need a lighter disabled fg - but only if !black
disfg = disfg.light(highlightVal);
else
// black fg - use darkgray disabled fg
- disfg = Qt::darkGray;
+ disfg = TQt::darkGray;
TQColorGroup disabledgrp(disfg, background,
@@ -2500,12 +2500,12 @@ TQPalette TDEApplication::createApplicationPalette( TDEConfig *config, int contr
if (v > 128)
// dark button, light buttonText - need a darker disabled buttonText
disbtntext = disbtntext.dark(lowlightVal);
- else if (disbtntext != Qt::black)
+ else if (disbtntext != TQt::black)
// light buttonText, dark button - need a lighter disabled buttonText - but only if !black
disbtntext = disbtntext.light(highlightVal);
else
// black button - use darkgray disabled buttonText
- disbtntext = Qt::darkGray;
+ disbtntext = TQt::darkGray;
disabledgrp.setColor(TQColorGroup::ButtonText, disbtntext);
disabledgrp.setColor(TQColorGroup::Midlight, background.light(110));
@@ -2591,15 +2591,15 @@ void TDEApplication::propagateSettings(SettingsCategory arg)
TQApplication::setWheelScrollLines(num);
bool b = config->readBoolEntry("EffectAnimateMenu", false);
- TQApplication::setEffectEnabled( Qt::UI_AnimateMenu, b);
+ TQApplication::setEffectEnabled( TQt::UI_AnimateMenu, b);
b = config->readBoolEntry("EffectFadeMenu", false);
- TQApplication::setEffectEnabled( Qt::UI_FadeMenu, b);
+ TQApplication::setEffectEnabled( TQt::UI_FadeMenu, b);
b = config->readBoolEntry("EffectAnimateCombo", false);
- TQApplication::setEffectEnabled( Qt::UI_AnimateCombo, b);
+ TQApplication::setEffectEnabled( TQt::UI_AnimateCombo, b);
b = config->readBoolEntry("EffectAnimateTooltip", false);
- TQApplication::setEffectEnabled( Qt::UI_AnimateTooltip, b);
+ TQApplication::setEffectEnabled( TQt::UI_AnimateTooltip, b);
b = config->readBoolEntry("EffectFadeTooltip", false);
- TQApplication::setEffectEnabled( Qt::UI_FadeTooltip, b);
+ TQApplication::setEffectEnabled( TQt::UI_FadeTooltip, b);
b = !config->readBoolEntry("EffectNoTooltip", false);
TQToolTip::setGloballyEnabled( b );
@@ -3632,7 +3632,7 @@ uint TDEApplication::mouseState()
return mousestate & 0xff00;
}
-Qt::ButtonState TDEApplication::keyboardMouseState()
+TQt::ButtonState TDEApplication::keyboardMouseState()
{
int ret = 0;
#ifdef Q_WS_X11
diff --git a/tdecore/tdeapplication.h b/tdecore/tdeapplication.h
index d7fa84e92..ee2b482a6 100644
--- a/tdecore/tdeapplication.h
+++ b/tdecore/tdeapplication.h
@@ -187,7 +187,7 @@ public:
*
* @see RGBADisplay()
*/
- TDEApplication(Display *display, bool disable_argb, Qt::HANDLE visual, Qt::HANDLE colormap, bool allowStyles);
+ TDEApplication(Display *display, bool disable_argb, TQt::HANDLE visual, TQt::HANDLE colormap, bool allowStyles);
/**
* Constructor. Parses command-line arguments. Use this constructor when you
@@ -212,7 +212,7 @@ public:
*
* @since KDE 3.3
*/
- TDEApplication(Display *display, Qt::HANDLE visual = 0, Qt::HANDLE colormap = 0,
+ TDEApplication(Display *display, TQt::HANDLE visual = 0, TQt::HANDLE colormap = 0,
bool allowStyles=true);
/**
@@ -984,14 +984,14 @@ public:
*
* @return A pointer to the X11 display visual
*/
- Qt::HANDLE getX11RGBAVisual(Display *dpy);
+ TQt::HANDLE getX11RGBAVisual(Display *dpy);
/**
* Returns the X11 display colormap
*
* @return An X11 display colormap object
*/
- Qt::HANDLE getX11RGBAColormap(Display *dpy);
+ TQt::HANDLE getX11RGBAColormap(Display *dpy);
/**
* Returns whether or not X11 composition is available
@@ -1266,7 +1266,7 @@ protected:
/**
* @internal Used by KUniqueApplication
*/
- TDEApplication( Display *display, Qt::HANDLE visual, Qt::HANDLE colormap,
+ TDEApplication( Display *display, TQt::HANDLE visual, TQt::HANDLE colormap,
bool allowStyles, TDEInstance* _instance );
/**
@@ -1353,8 +1353,8 @@ private:
bool argb_visual;
#if defined(Q_WS_X11)
- Qt::HANDLE argb_x11_visual;
- Qt::HANDLE argb_x11_colormap;
+ TQt::HANDLE argb_x11_visual;
+ TQt::HANDLE argb_x11_colormap;
#endif
public:
diff --git a/tdecore/tdeconfigdialogmanager.cpp b/tdecore/tdeconfigdialogmanager.cpp
index 016009c18..f53ce3a30 100644
--- a/tdecore/tdeconfigdialogmanager.cpp
+++ b/tdecore/tdeconfigdialogmanager.cpp
@@ -187,7 +187,7 @@ bool TDEConfigDialogManager::parseChildren(const TQWidget *widget, bool trackCha
{
// If the class name of the widget wasn't in the monitored widgets map, then look for
// it again using the super class name. This fixes a problem with using QtRuby/Korundum
- // widgets with TDEConfigXT where 'Qt::Widget' wasn't being seen a the real deal, even
+ // widgets with TDEConfigXT where 'TQt::Widget' wasn't being seen a the real deal, even
// though it was a 'TQWidget'.
changedIt = changedMap.find(childWidget->metaObject()->superClassName());
}
diff --git a/tdecore/tdeglobalsettings.cpp b/tdecore/tdeglobalsettings.cpp
index 11f5a0497..20a8d3866 100644
--- a/tdecore/tdeglobalsettings.cpp
+++ b/tdecore/tdeglobalsettings.cpp
@@ -429,7 +429,7 @@ TQColor TDEGlobalSettings::alternateBackgroundColor()
TQColor TDEGlobalSettings::calculateAlternateBackgroundColor(const TQColor& base)
{
- if (base == Qt::white)
+ if (base == TQt::white)
return TQColor(238,246,255);
else
{
@@ -437,7 +437,7 @@ TQColor TDEGlobalSettings::calculateAlternateBackgroundColor(const TQColor& base
base.hsv( &h, &s, &v );
if (v > 128)
return base.dark(106);
- else if (base != Qt::black)
+ else if (base != TQt::black)
return base.light(110);
return TQColor(32,32,32);
diff --git a/tdecore/tdeshortcut.cpp b/tdecore/tdeshortcut.cpp
index 86b532f9c..e3c82ce7e 100644
--- a/tdecore/tdeshortcut.cpp
+++ b/tdecore/tdeshortcut.cpp
@@ -89,10 +89,10 @@ bool KKey::init( const TQKeySequence& key )
bool KKey::init( const TQKeyEvent* pEvent )
{
int keyQt = pEvent->key();
- if( pEvent->state() & TQt::ShiftButton ) keyQt |= Qt::SHIFT;
- if( pEvent->state() & TQt::ControlButton ) keyQt |= Qt::CTRL;
- if( pEvent->state() & TQt::AltButton ) keyQt |= Qt::ALT;
- if( pEvent->state() & TQt::MetaButton ) keyQt |= Qt::META;
+ if( pEvent->state() & TQt::ShiftButton ) keyQt |= TQt::SHIFT;
+ if( pEvent->state() & TQt::ControlButton ) keyQt |= TQt::CTRL;
+ if( pEvent->state() & TQt::AltButton ) keyQt |= TQt::ALT;
+ if( pEvent->state() & TQt::MetaButton ) keyQt |= TQt::META;
return init( keyQt );
}
diff --git a/tdecore/tdeshortcutmenu.cpp b/tdecore/tdeshortcutmenu.cpp
index fe868c68a..bf381bf78 100644
--- a/tdecore/tdeshortcutmenu.cpp
+++ b/tdecore/tdeshortcutmenu.cpp
@@ -104,8 +104,8 @@ void TDEShortcutMenu::keyPressEvent( TQKeyEvent* pEvent )
if( iItem == -1 ) {
// Let Up and Down keys navigate menu,
// And permit Enter, Return to select the item.
- if( pEvent->key() == Qt::Key_Up || pEvent->key() == Qt::Key_Down ||
- pEvent->key() == Qt::Key_Enter || pEvent->key() == Qt::Key_Return )
+ if( pEvent->key() == TQt::Key_Up || pEvent->key() == TQt::Key_Down ||
+ pEvent->key() == TQt::Key_Enter || pEvent->key() == TQt::Key_Return )
TQPopupMenu::keyPressEvent( pEvent );
else
close();
diff --git a/tdecore/tdestdaccel.cpp b/tdecore/tdestdaccel.cpp
index ba3e64ca5..b26948fd0 100644
--- a/tdecore/tdestdaccel.cpp
+++ b/tdecore/tdestdaccel.cpp
@@ -50,59 +50,59 @@ struct TDEStdAccelInfo
static TDEStdAccelInfo g_infoStdAccel[] =
{
{AccelNone, "Group:File", I18N_NOOP("File"), 0, 0, 0, 0, TDEShortcut(), false },
- { Open, I18N_NOOP("Open"), 0, Qt::CTRL+Qt::Key_O, 0, 0, 0, TDEShortcut(), false },
- { New, I18N_NOOP("New"), 0, Qt::CTRL+Qt::Key_N, 0, 0, 0, TDEShortcut(), false },
- { Close, I18N_NOOP("Close"), 0, Qt::CTRL+Qt::Key_W, Qt::CTRL+Qt::Key_Escape, 0, Qt::CTRL+Qt::Key_W, TDEShortcut(), false },
- { Save, I18N_NOOP("Save"), 0, Qt::CTRL+Qt::Key_S, 0, 0, 0, TDEShortcut(), false },
- { Print, I18N_NOOP("Print"), 0, Qt::CTRL+Qt::Key_P, 0, 0, 0, TDEShortcut(), false },
- { Quit, I18N_NOOP("Quit"), 0, Qt::CTRL+Qt::Key_Q, 0, 0, 0, TDEShortcut(), false },
+ { Open, I18N_NOOP("Open"), 0, TQt::CTRL+TQt::Key_O, 0, 0, 0, TDEShortcut(), false },
+ { New, I18N_NOOP("New"), 0, TQt::CTRL+TQt::Key_N, 0, 0, 0, TDEShortcut(), false },
+ { Close, I18N_NOOP("Close"), 0, TQt::CTRL+TQt::Key_W, TQt::CTRL+TQt::Key_Escape, 0, TQt::CTRL+TQt::Key_W, TDEShortcut(), false },
+ { Save, I18N_NOOP("Save"), 0, TQt::CTRL+TQt::Key_S, 0, 0, 0, TDEShortcut(), false },
+ { Print, I18N_NOOP("Print"), 0, TQt::CTRL+TQt::Key_P, 0, 0, 0, TDEShortcut(), false },
+ { Quit, I18N_NOOP("Quit"), 0, TQt::CTRL+TQt::Key_Q, 0, 0, 0, TDEShortcut(), false },
{AccelNone, "Group:Edit", I18N_NOOP("Edit"), 0, 0, 0, 0, TDEShortcut(), false },
- { Undo, I18N_NOOP("Undo"), 0, Qt::CTRL+Qt::Key_Z, 0, 0, 0, TDEShortcut(), false },
- { Redo, I18N_NOOP("Redo"), 0, Qt::CTRL+Qt::SHIFT+Qt::Key_Z, 0, 0, 0, TDEShortcut(), false },
- { Cut, I18N_NOOP("Cut"), 0, Qt::CTRL+Qt::Key_X, 0, Qt::SHIFT+Qt::Key_Delete, 0, TDEShortcut(), false },
- { Copy, I18N_NOOP("Copy"), 0, Qt::CTRL+Qt::Key_C, 0, Qt::CTRL+Qt::Key_Insert, 0, TDEShortcut(), false },
- { Paste, I18N_NOOP("Paste"), 0, Qt::CTRL+Qt::Key_V, 0, Qt::SHIFT+Qt::Key_Insert, 0, TDEShortcut(), false },
- { PasteSelection, I18N_NOOP("Paste Selection"), 0, 0, 0, Qt::CTRL+Qt::SHIFT+Qt::Key_Insert, 0, TDEShortcut(), false },
- { SelectAll, "SelectAll", I18N_NOOP("Select All"), Qt::CTRL+Qt::Key_A, 0, 0, 0, TDEShortcut(), false },
- { Deselect, I18N_NOOP("Deselect"), 0, Qt::CTRL+Qt::SHIFT+Qt::Key_A, 0, 0, 0, TDEShortcut(), false },
- { DeleteWordBack, "DeleteWordBack", I18N_NOOP("Delete Word Backwards"), Qt::CTRL+Qt::Key_Backspace, 0, 0, 0, TDEShortcut(), false },
- { DeleteWordForward, "DeleteWordForward", I18N_NOOP("Delete Word Forward"), Qt::CTRL+Qt::Key_Delete, 0, 0, 0, TDEShortcut(), false },
- { Find, I18N_NOOP("Find"), 0, Qt::CTRL+Qt::Key_F, 0, 0, 0, TDEShortcut(), false },
- { FindNext, "FindNext", I18N_NOOP("Find Next"), Qt::Key_F3, 0, 0, 0, TDEShortcut(), false },
- { FindPrev, "FindPrev", I18N_NOOP("Find Prev"), Qt::SHIFT+Qt::Key_F3, 0, 0, 0, TDEShortcut(), false },
- { Replace, I18N_NOOP("Replace"), 0, Qt::CTRL+Qt::Key_R, 0, 0, 0, TDEShortcut(), false },
+ { Undo, I18N_NOOP("Undo"), 0, TQt::CTRL+TQt::Key_Z, 0, 0, 0, TDEShortcut(), false },
+ { Redo, I18N_NOOP("Redo"), 0, TQt::CTRL+TQt::SHIFT+TQt::Key_Z, 0, 0, 0, TDEShortcut(), false },
+ { Cut, I18N_NOOP("Cut"), 0, TQt::CTRL+TQt::Key_X, 0, TQt::SHIFT+TQt::Key_Delete, 0, TDEShortcut(), false },
+ { Copy, I18N_NOOP("Copy"), 0, TQt::CTRL+TQt::Key_C, 0, TQt::CTRL+TQt::Key_Insert, 0, TDEShortcut(), false },
+ { Paste, I18N_NOOP("Paste"), 0, TQt::CTRL+TQt::Key_V, 0, TQt::SHIFT+TQt::Key_Insert, 0, TDEShortcut(), false },
+ { PasteSelection, I18N_NOOP("Paste Selection"), 0, 0, 0, TQt::CTRL+TQt::SHIFT+TQt::Key_Insert, 0, TDEShortcut(), false },
+ { SelectAll, "SelectAll", I18N_NOOP("Select All"), TQt::CTRL+TQt::Key_A, 0, 0, 0, TDEShortcut(), false },
+ { Deselect, I18N_NOOP("Deselect"), 0, TQt::CTRL+TQt::SHIFT+TQt::Key_A, 0, 0, 0, TDEShortcut(), false },
+ { DeleteWordBack, "DeleteWordBack", I18N_NOOP("Delete Word Backwards"), TQt::CTRL+TQt::Key_Backspace, 0, 0, 0, TDEShortcut(), false },
+ { DeleteWordForward, "DeleteWordForward", I18N_NOOP("Delete Word Forward"), TQt::CTRL+TQt::Key_Delete, 0, 0, 0, TDEShortcut(), false },
+ { Find, I18N_NOOP("Find"), 0, TQt::CTRL+TQt::Key_F, 0, 0, 0, TDEShortcut(), false },
+ { FindNext, "FindNext", I18N_NOOP("Find Next"), TQt::Key_F3, 0, 0, 0, TDEShortcut(), false },
+ { FindPrev, "FindPrev", I18N_NOOP("Find Prev"), TQt::SHIFT+TQt::Key_F3, 0, 0, 0, TDEShortcut(), false },
+ { Replace, I18N_NOOP("Replace"), 0, TQt::CTRL+TQt::Key_R, 0, 0, 0, TDEShortcut(), false },
{AccelNone, "Group:Navigation", I18N_NOOP("Navigation"), 0, 0, 0, 0, TDEShortcut(), false },
- { Home, I18N_NOOP2("Opposite to End","Home"), 0, Qt::CTRL+Qt::Key_Home, 0, Qt::Key_HomePage, 0, TDEShortcut(), false },
- { End, I18N_NOOP("End"), 0, Qt::CTRL+Qt::Key_End, 0, 0, 0, TDEShortcut(), false },
- { BeginningOfLine, "BeginningOfLine", I18N_NOOP("Beginning of Line"), Qt::Key_Home, 0, 0, 0, TDEShortcut(), false},
- { EndOfLine, "EndOfLine", I18N_NOOP("End of Line"), Qt::Key_End, 0, 0, 0, TDEShortcut(), false},
+ { Home, I18N_NOOP2("Opposite to End","Home"), 0, TQt::CTRL+TQt::Key_Home, 0, TQt::Key_HomePage, 0, TDEShortcut(), false },
+ { End, I18N_NOOP("End"), 0, TQt::CTRL+TQt::Key_End, 0, 0, 0, TDEShortcut(), false },
+ { BeginningOfLine, "BeginningOfLine", I18N_NOOP("Beginning of Line"), TQt::Key_Home, 0, 0, 0, TDEShortcut(), false},
+ { EndOfLine, "EndOfLine", I18N_NOOP("End of Line"), TQt::Key_End, 0, 0, 0, TDEShortcut(), false},
{ Prior, I18N_NOOP("Prior"), 0, TQt::Key_Prior, 0, 0, 0, TDEShortcut(), false },
{ Next, I18N_NOOP2("Opposite to Prior","Next"), 0, TQt::Key_Next, 0, 0, 0, TDEShortcut(), false },
- { GotoLine, "GotoLine", I18N_NOOP("Go to Line"), Qt::CTRL+Qt::Key_G, 0, 0, 0, TDEShortcut(), false },
- { AddBookmark, "AddBookmark", I18N_NOOP("Add Bookmark"), Qt::CTRL+Qt::Key_B, 0, 0, 0, TDEShortcut(), false },
- { ZoomIn, "ZoomIn", I18N_NOOP("Zoom In"), Qt::CTRL+Qt::Key_Plus, 0, 0, 0, TDEShortcut(), false },
- { ZoomOut, "ZoomOut", I18N_NOOP("Zoom Out"), Qt::CTRL+Qt::Key_Minus, 0, 0, 0, TDEShortcut(), false },
- { Up, I18N_NOOP("Up"), 0, Qt::ALT+Qt::Key_Up, 0, 0, 0, TDEShortcut(), false },
- { Back, I18N_NOOP("Back"), 0, Qt::ALT+Qt::Key_Left, 0, Qt::Key_Back, 0, TDEShortcut(), false },
- { Forward, I18N_NOOP("Forward"), 0, Qt::ALT+Qt::Key_Right, 0, Qt::Key_Forward, 0, TDEShortcut(), false },
- { Reload, I18N_NOOP("Reload"), 0, Qt::Key_F5, 0, Qt::Key_Refresh, 0, TDEShortcut(), false },
- { PopupMenuContext, "PopupMenuContext", I18N_NOOP("Popup Menu Context"), Qt::Key_Menu, 0, 0, 0, TDEShortcut(), false },
- { ShowMenubar, "ShowMenubar", I18N_NOOP("Show Menu Bar"), Qt::CTRL+Qt::Key_M, 0, 0, 0, TDEShortcut(), false },
- { BackwardWord, "BackwardWord", I18N_NOOP("Backward Word"), Qt::CTRL+Qt::Key_Left, 0, 0, 0, TDEShortcut(), false },
- { ForwardWord, "ForwardWord", I18N_NOOP("Forward Word"), Qt::CTRL+Qt::Key_Right, 0, 0, 0, TDEShortcut(), false },
- { TabNext, I18N_NOOP("Activate Next Tab"), 0, Qt::CTRL+Qt::Key_Period, 0, Qt::CTRL+Qt::Key_BracketRight, 0, TDEShortcut(), false },
- { TabPrev, I18N_NOOP("Activate Previous Tab"), 0, Qt::CTRL+Qt::Key_Comma, 0, Qt::CTRL+Qt::Key_BracketLeft, 0, TDEShortcut(), false },
- { FullScreen, "FullScreen", I18N_NOOP("Full Screen Mode"), Qt::CTRL+Qt::SHIFT+Qt::Key_F, 0, 0, 0, TDEShortcut(), false },
+ { GotoLine, "GotoLine", I18N_NOOP("Go to Line"), TQt::CTRL+TQt::Key_G, 0, 0, 0, TDEShortcut(), false },
+ { AddBookmark, "AddBookmark", I18N_NOOP("Add Bookmark"), TQt::CTRL+TQt::Key_B, 0, 0, 0, TDEShortcut(), false },
+ { ZoomIn, "ZoomIn", I18N_NOOP("Zoom In"), TQt::CTRL+TQt::Key_Plus, 0, 0, 0, TDEShortcut(), false },
+ { ZoomOut, "ZoomOut", I18N_NOOP("Zoom Out"), TQt::CTRL+TQt::Key_Minus, 0, 0, 0, TDEShortcut(), false },
+ { Up, I18N_NOOP("Up"), 0, TQt::ALT+TQt::Key_Up, 0, 0, 0, TDEShortcut(), false },
+ { Back, I18N_NOOP("Back"), 0, TQt::ALT+TQt::Key_Left, 0, TQt::Key_Back, 0, TDEShortcut(), false },
+ { Forward, I18N_NOOP("Forward"), 0, TQt::ALT+TQt::Key_Right, 0, TQt::Key_Forward, 0, TDEShortcut(), false },
+ { Reload, I18N_NOOP("Reload"), 0, TQt::Key_F5, 0, TQt::Key_Refresh, 0, TDEShortcut(), false },
+ { PopupMenuContext, "PopupMenuContext", I18N_NOOP("Popup Menu Context"), TQt::Key_Menu, 0, 0, 0, TDEShortcut(), false },
+ { ShowMenubar, "ShowMenubar", I18N_NOOP("Show Menu Bar"), TQt::CTRL+TQt::Key_M, 0, 0, 0, TDEShortcut(), false },
+ { BackwardWord, "BackwardWord", I18N_NOOP("Backward Word"), TQt::CTRL+TQt::Key_Left, 0, 0, 0, TDEShortcut(), false },
+ { ForwardWord, "ForwardWord", I18N_NOOP("Forward Word"), TQt::CTRL+TQt::Key_Right, 0, 0, 0, TDEShortcut(), false },
+ { TabNext, I18N_NOOP("Activate Next Tab"), 0, TQt::CTRL+TQt::Key_Period, 0, TQt::CTRL+TQt::Key_BracketRight, 0, TDEShortcut(), false },
+ { TabPrev, I18N_NOOP("Activate Previous Tab"), 0, TQt::CTRL+TQt::Key_Comma, 0, TQt::CTRL+TQt::Key_BracketLeft, 0, TDEShortcut(), false },
+ { FullScreen, "FullScreen", I18N_NOOP("Full Screen Mode"), TQt::CTRL+TQt::SHIFT+TQt::Key_F, 0, 0, 0, TDEShortcut(), false },
{AccelNone, "Group:Help", I18N_NOOP("Help"), 0, 0, 0, 0, TDEShortcut(), false },
- { Help, I18N_NOOP("Help"), 0, Qt::Key_F1, 0, 0, 0, TDEShortcut(), false },
- { WhatsThis, "WhatsThis", I18N_NOOP("What's This"), Qt::SHIFT+Qt::Key_F1, 0, 0, 0, TDEShortcut(), false },
+ { Help, I18N_NOOP("Help"), 0, TQt::Key_F1, 0, 0, 0, TDEShortcut(), false },
+ { WhatsThis, "WhatsThis", I18N_NOOP("What's This"), TQt::SHIFT+TQt::Key_F1, 0, 0, 0, TDEShortcut(), false },
{AccelNone, "Group:TextCompletion", I18N_NOOP("Text Completion"), 0, 0, 0, 0, TDEShortcut(), false },
- { TextCompletion, "TextCompletion", I18N_NOOP("Text Completion"), Qt::CTRL+Qt::Key_E, 0, 0, 0, TDEShortcut(), false },
- { PrevCompletion, "PrevCompletion", I18N_NOOP("Previous Completion Match"), Qt::CTRL+Qt::Key_Up, 0, 0, 0, TDEShortcut(), false },
- { NextCompletion, "NextCompletion", I18N_NOOP("Next Completion Match"), Qt::CTRL+Qt::Key_Down, 0, 0, 0, TDEShortcut(), false },
- { SubstringCompletion, "SubstringCompletion", I18N_NOOP("Substring Completion"), Qt::CTRL+Qt::Key_T, 0, 0, 0, TDEShortcut(), false },
- { RotateUp, "RotateUp", I18N_NOOP("Previous Item in List"), Qt::Key_Up, 0, 0, 0, TDEShortcut(), false },
- { RotateDown, "RotateDown", I18N_NOOP("Next Item in List"), Qt::Key_Down, 0, 0, 0, TDEShortcut(), false },
+ { TextCompletion, "TextCompletion", I18N_NOOP("Text Completion"), TQt::CTRL+TQt::Key_E, 0, 0, 0, TDEShortcut(), false },
+ { PrevCompletion, "PrevCompletion", I18N_NOOP("Previous Completion Match"), TQt::CTRL+TQt::Key_Up, 0, 0, 0, TDEShortcut(), false },
+ { NextCompletion, "NextCompletion", I18N_NOOP("Next Completion Match"), TQt::CTRL+TQt::Key_Down, 0, 0, 0, TDEShortcut(), false },
+ { SubstringCompletion, "SubstringCompletion", I18N_NOOP("Substring Completion"), TQt::CTRL+TQt::Key_T, 0, 0, 0, TDEShortcut(), false },
+ { RotateUp, "RotateUp", I18N_NOOP("Previous Item in List"), TQt::Key_Up, 0, 0, 0, TDEShortcut(), false },
+ { RotateDown, "RotateDown", I18N_NOOP("Next Item in List"), TQt::Key_Down, 0, 0, 0, TDEShortcut(), false },
{ AccelNone, 0, 0, 0, 0, 0, 0, TDEShortcut(), false }
};
diff --git a/tdecore/tests/kdebugtest.cpp b/tdecore/tests/kdebugtest.cpp
index 00f43425c..9f07b3437 100644
--- a/tdecore/tests/kdebugtest.cpp
+++ b/tdecore/tests/kdebugtest.cpp
@@ -64,7 +64,7 @@ public:
TQVariant v( 0.12345 );
kdDebug() << "Variant: " << v << endl;
- v = TQPen( Qt::red );
+ v = TQPen( TQt::red );
kdDebug() << "Variant: " << v << endl;
TQByteArray data( 6 );
diff --git a/tdecore/tests/ktimezonestest.cpp b/tdecore/tests/ktimezonestest.cpp
index d00626cdf..a42c5a395 100644
--- a/tdecore/tests/ktimezonestest.cpp
+++ b/tdecore/tests/ktimezonestest.cpp
@@ -22,8 +22,8 @@ int main(int argc, char *argv[])
// Find some offsets for Europe/London.
const char *london = "Europe/London";
timezone = timezones.zone(london);
- TQDateTime winter(TQDateTime::fromString("2005-01-01T00:00:00", Qt::ISODate));
- TQDateTime summer(TQDateTime::fromString("2005-06-01T00:00:00", Qt::ISODate));
+ TQDateTime winter(TQDateTime::fromString("2005-01-01T00:00:00", TQt::ISODate));
+ TQDateTime summer(TQDateTime::fromString("2005-06-01T00:00:00", TQt::ISODate));
printf( "%s winter timezone offset should be 0: %d\n", london, timezone->offset(winter) );
printf( "%s summer timezone offset should be 3600: %d\n", london, timezone->offset(summer) );
@@ -34,13 +34,13 @@ int main(int argc, char *argv[])
const char *gmtBeforePst = "2005-10-30T01:00:00";
const char *gmtAfterPst = "2005-12-01T00:00:00";
TQString result;
- result = timezone->convert(losAngeles, TQDateTime::fromString(bstBeforePdt, Qt::ISODate)).toString(Qt::ISODate);
+ result = timezone->convert(losAngeles, TQDateTime::fromString(bstBeforePdt, TQt::ISODate)).toString(TQt::ISODate);
printf( "BST before PDT, %s should be 2005-03-27T15:00:00: %s\n", bstBeforePdt, result.latin1() );
- result = timezone->convert(losAngeles, TQDateTime::fromString(bstAfterPdt, Qt::ISODate)).toString(Qt::ISODate);
+ result = timezone->convert(losAngeles, TQDateTime::fromString(bstAfterPdt, TQt::ISODate)).toString(TQt::ISODate);
printf( "BST and PDT, %s should be 2005-04-30T16:00:00: %s\n", bstAfterPdt, result.latin1() );
- result = timezone->convert(losAngeles, TQDateTime::fromString(gmtBeforePst, Qt::ISODate)).toString(Qt::ISODate);
+ result = timezone->convert(losAngeles, TQDateTime::fromString(gmtBeforePst, TQt::ISODate)).toString(TQt::ISODate);
printf( "GMT before PST, %s should be 2005-10-29T17:00:00: %s\n", gmtBeforePst, result.latin1() );
- result = timezone->convert(losAngeles, TQDateTime::fromString(gmtAfterPst, Qt::ISODate)).toString(Qt::ISODate);
+ result = timezone->convert(losAngeles, TQDateTime::fromString(gmtAfterPst, TQt::ISODate)).toString(TQt::ISODate);
printf( "GMT and PST, %s should be 2005-11-30T16:00:00: %s\n", gmtAfterPst, result.latin1() );
printf( "Latitude 89 should be valid: %svalid\n", KTimezone::isValidLatitude(89.0) ? "" : "in");
printf( "Latitude 91 should be invalid: %svalid\n", KTimezone::isValidLatitude(91.0) ? "" : "in");
diff --git a/tdecore/tdeshortcut.h b/tdecore/tdeshortcut.h
index 09f7fce05..407d558a8 100644
--- a/tdecore/tdeshortcut.h
+++ b/tdecore/tdeshortcut.h
@@ -45,7 +45,7 @@ class TDECORE_EXPORT KKey
* @see ModFlag
*/
enum { MOD_FLAG_COUNT = 4 };
- enum { QtWIN = (Qt::META) };
+ enum { QtWIN = (TQt::META) };
/**
* Flags to represent the modifiers. You can combine modifiers
* by ORing them.
@@ -68,7 +68,7 @@ class TDECORE_EXPORT KKey
/**
* Creates a new key for the given Qt key code.
* @param keyQt the qt keycode
- * @see Qt::Key
+ * @see TQt::Key
*/
KKey( int keyQt );
@@ -115,7 +115,7 @@ class TDECORE_EXPORT KKey
* Initializes the key with the given Qt key code.
* @param keyQt the qt keycode
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
*/
bool init( int keyQt );
@@ -217,7 +217,7 @@ class TDECORE_EXPORT KKey
/**
* Returns the qt key code.
* @return the qt key code or 0 if there is no key set.
- * @see Qt::Key
+ * @see TQt::Key
*/
int keyCodeQt() const;
@@ -469,7 +469,7 @@ class TDECORE_EXPORT KKeySequence
*/
bool operator < ( const KKeySequence& seq ) const
{ return compare( seq ) < 0; }
// TODO: consider adding Qt::SequenceMatch matches(...) methods for TQKeySequence equivalence
/**
* Converts this key sequence to a TQKeySequence.
@@ -480,7 +480,7 @@ class TDECORE_EXPORT KKeySequence
/**
* Returns the qt key code of the first key.
* @return the qt key code of the first key
- * @see Qt::Key
+ * @see TQt::Key
* @see KKey::keyCodeQt()
*/
int keyCodeQt() const;
@@ -561,7 +561,7 @@ class TDECORE_EXPORT TDEShortcut
* Creates a new shortcut with the given Qt key code
* as the only key sequence.
* @param keyQt the qt keycode
- * @see Qt::Key
+ * @see TQt::Key
*/
TDEShortcut( int keyQt );
@@ -622,7 +622,7 @@ class TDECORE_EXPORT TDEShortcut
* Initializes the shortcut with the given Qt key code
* as the only key sequence.
* @param keyQt the qt keycode
- * @see Qt::Key
+ * @see TQt::Key
*/
bool init( int keyQt );
@@ -686,7 +686,7 @@ class TDECORE_EXPORT TDEShortcut
* Returns the key code of the first key sequence, or
* null if there is no first key sequence.
* @return the key code of the first sequence's first key
- * @see Qt::Key
+ * @see TQt::Key
* @see KKeySequence::keyCodeQt()
*/
int keyCodeQt() const;
@@ -469,7 +469,7 @@ class TDECORE_EXPORT KKeySequence
bool operator < ( const KKeySequence& seq ) const
{ return compare( seq ) < 0; }
- // TODO: consider adding Qt::SequenceMatch matches(...) methods for TQKeySequence equivalence
+ // TODO: consider adding TQt::SequenceMatch matches(...) methods for TQKeySequence equivalence
/**
* Converts this key sequence to a TQKeySequence.